@@ -46,7 +46,8 @@ CONFIG_FILE_EXT = ".json"
 CONFIG_FILE_SCHEMA = f"{CONFIG_FOLDER}/config_{SCHEMA}.json"
 CONFIG_REFRESH_RATE = "refresh_rate_seconds"
 CONFIG_OPTIMIZER_ID = "optimizer_id"
-CONFIG_TENTACLES_REQUIRED_CANDLES_COUNT = "required_candles_count"
+CONFIG_BACKTESTING_ID = "backtesting_id"
+CONFIG_SAVED_HISTORICAL_TIMEFRAMES = "saved_historical_timeframes"
 
 # profiles
 PROFILES_FOLDER = "profiles"
@@ -95,6 +96,7 @@ CONFIG_TRADING = "trading"
 CONFIG_TRADER = "trader"
 CONFIG_LOAD_TRADE_HISTORY = "load-trade-history"
 CONFIG_TRADER_RISK = "risk"
+CONFIG_TRADER_ALLOW_ARTIFICIAL_ORDERS = "allow-artificial-orders"
 CONFIG_TRADER_RISK_MIN = 0.05
 CONFIG_TRADER_RISK_MAX = 1
 CONFIG_TRADER_REFERENCE_MARKET = "reference-market"
@@ -108,6 +110,9 @@ CONFIG_SIMULATOR_FEES_MAKER = "maker"
 CONFIG_SIMULATOR_FEES_TAKER = "taker"
 CONFIG_SIMULATOR_FEES_WITHDRAW = "withdraw"
 
+# Optimization campaigns
+DEFAULT_CAMPAIGN = "default_campaign"
+
 # Optimizer
 OPTIMIZER_RUNS_FOLDER = "optimizer"
 
@@ -122,6 +127,12 @@ START_PENDING_EVAL_NOTE = "0"
 # tentacles
 TENTACLE_DEFAULT_CONFIG = "default_config"
 CONFIG_TENTACLES_FILE = "tentacles_config.json"
+EVALUATOR_PRIORITY = "priority"
+DEFAULT_EVALUATOR_PRIORITY = 0
+CONFIG_TENTACLES_REQUIRED_CANDLES_COUNT = "required_candles_count"
+NESTED_TENTACLE_CONFIG = "nested_tentacle_configuration"
+CONFIG_ACTIVATION_TOPICS = "activation method"
+CONFIG_TRIGGER_TIMEFRAMES = "Trigger_timeframes"
 
 # terms of service
 CONFIG_ACCEPTED_TERMS = "accepted_terms"
@@ -141,7 +152,6 @@ METRICS_ROUTE_COMMUNITY = f"{METRICS_ROUTE}/community"
 METRICS_ROUTE_UPTIME = f"{METRICS_ROUTE}/uptime"
 METRICS_ROUTE_REGISTER = f"{METRICS_ROUTE}/register"
 COMMUNITY_TOPS_COUNT = 1000
-PLATFORM_DATA_SEPARATOR = ":"
 
 # default values in config files and interfaces
 DEFAULT_API_KEY = "your-api-key-here"
@@ -156,6 +166,17 @@ DEFAULT_CONFIG_VALUES = {
     "Empty",
 }
 
+# cache
+CACHE_FOLDER = "cache"
+CACHE_FILE = "cache.json"
+CACHE_HASH_SIZE = 15
+CACHE_RELATED_DATA_SEPARATOR = "##"
+LOCAL_BOT_DATA = "local_bot_data"
+DO_NOT_CACHE = "do_not_cache"
+DO_NOT_OVERRIDE_CACHE = "do_not_override_cache"
+DEFAULT_IGNORED_VALUE = -1
+UNPROVIDED_CACHE_IDENTIFIER = "_unprovided"
+
 # Async settings
 DEFAULT_FUTURE_TIMEOUT = 120
 
@@ -167,3 +188,10 @@ GITHUB_ORGANISATION = "Drakkar-Software"
 
 # External resources
 EXTERNAL_RESOURCE_URL = "https://raw.githubusercontent.com/Drakkar-Software/OctoBot/assets/external_resources.json"
+
+# Run databases
+DATA_FOLDER = "data"
+DB_SEPARATOR = "_"
+TINYDB_EXT = ".json"
+MAX_BACKTESTING_RUNS = 50000
+MAX_OPTIMIZER_RUNS = 50000
